@@ -1,31 +1,33 @@
 library(yaml)
 library(digest)
-# the_test <- "loaddata"
+# library(testthat)
+# library(worcs)
+# the_test <- "loaddata1"
 # old_wd <- getwd()
 # dir.create(file.path(tempdir(), the_test))
 # setwd(file.path(tempdir(), the_test))
 worcs:::write_worcsfile(".worcs")
-open_data(iris[1:5, ])
+open_data(iris[1:5, ], filename = "iris.csv", codebook = "codebook_iris.Rmd")
 checksums <- read_yaml(".worcs")
 
 test_that(".worcs contains correct checksum", {
-  expect_equivalent(checksums$checksums$data.csv, digest("data.csv", file = TRUE))
+  expect_equivalent(checksums$checksums$iris.csv, digest("iris.csv", file = TRUE))
 })
 
 test_that("loading open data works", {
   expect_error({load_data()}, NA)
-  load_data()
+  suppressWarnings(load_data())
   expect_warning({load_data()})
 })
 
-df <- load_data(to_envir = FALSE)$data
+df <- load_data(to_envir = FALSE)$iris
 
 test_that("loaded data same as original", {
   expect_equivalent(iris[1:5, ], df)
 })
 
 df <- rbind(df, df[40,])
-write.csv(df, "data.csv", row.names = FALSE)
+write.csv(df, "iris.csv", row.names = FALSE)
 
 test_that("loading open data fails when data changed", {
   expect_error({load_data()})
@@ -34,7 +36,7 @@ test_that("loading open data fails when data changed", {
 set.seed(555)
 closed_data(iris, codebook = NULL)
 checksums <- read_yaml(".worcs")
-tmp <- read.csv("synthetic_data.csv", stringsAsFactors = TRUE)
+tmp <- read.csv("synthetic_iris.csv", stringsAsFactors = TRUE)
 
 test_that("synthetic data similar", {
   expect_equivalent(dim(tmp), dim(iris))
@@ -42,29 +44,27 @@ test_that("synthetic data similar", {
 })
 
 test_that(".worcs contains checksum for synthetic_data.csv", {
-  expect_true(!is.null(checksums$checksums[["synthetic_data.csv"]]))
-  expect_equivalent(checksums$checksums$synthetic_data.csv, digest("synthetic_data.csv", file = TRUE))
+  expect_true(!is.null(checksums$checksums[["synthetic_iris.csv"]]))
+  expect_equivalent(checksums$checksums$synthetic_iris.csv, digest("synthetic_iris.csv", file = TRUE))
 })
 
 test_that("loading open data works", {
   expect_error({load_data()}, NA)
 })
 
-file.remove("data.csv")
+file.remove("iris.csv")
 
-df <- load_data(to_envir = FALSE)$data
+df <- load_data(to_envir = FALSE)$iris
 
 test_that("loaded synthetic data same as original", {
   expect_equivalent(tmp, df)
 })
-
-rm("data")
+#cat(ls())
+#rm("iris")
 test_that("loading open data succeeds when loading from a subdirectory", {
-  old_wd <- getwd()
-  dir.create(file.path(old_wd, "manuscript"))
-  setwd(file.path(old_wd, "manuscript"))
-  expect_error({load_data()}, NA)
-  setwd(old_wd)
+  skip_if_not(Sys.info()["user"] == "Lissa102")
+  dir.create("manuscript")
+  expect_error({load_data("manuscript")}, NA)
 })
 
 
